# Release 1.3.0
This is a major release because it removes Python 2 support. Any other changes are minor.

## Changes for developers
- Added pre-commit checking for formatting, flake8 and isort
- Uses Black for formatting
- Added a system test for checking that the overall system is functioning
- Added scripts for running lewis and lewis-control without installing
